# Table of Contents

- [integration-api](<./integration-api.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Integration API](<./Integration-API.md>)
  - [Overview](<./Integration-API/Overview.md>)
  - [Advantages](<./Integration-API/Advantages.md>)
  - [Inbound and Outbound Data Processors](<./Integration-API/Inbound-and-Outbound-Data-Processors.md>)
  - [LeanIX Data Interchange Format (LDIF)](<./Integration-API/LeanIX-Data-Interchange-Format-LDIF.md>)
  - [Mandatory Attributes](<./Integration-API/Mandatory-Attributes.md>)
  - [Content Array](<./Integration-API/Content-Array.md>)
  - [Integration REST API](<./Integration-API/Integration-REST-API.md>)
  - [Grouped Execution of Multiple Configurations](<./Integration-API/Grouped-Execution-of-Multiple-Configurations.md>)
  - [Comments in Processors](<./Integration-API/Comments-in-Processors.md>)
  - [Was this page helpful?](<./Integration-API/Was-this-page-helpful.md>)
